@@ -1,5 +1,5 @@
-#!/usr/bin/env ruby
-#
+# encoding: utf-8
+
 # = plist
 #
 # This is the main file for plist. Everything interesting happens in
@@ -13,9 +13,6 @@ require 'base64'
 require 'cgi'
 require 'stringio'
 
-require 'plist/generator'
-require 'plist/parser'
-
-module Plist
-  VERSION = '3.2.0'
-end
+require_relative 'plist/generator'
+require_relative 'plist/parser'
+require_relative 'plist/version'
